#[repr(u8)]pub enum Automatchread {
I2C_WRITE = 0,
I2C_READ = 1,
}Variants
I2C_WRITE = 0
The expected next operation in Automatic Mode is an I2C write.
I2C_READ = 1
The expected next operation in Automatic Mode is an I2C read.
Implementations
Sourceimpl Automatchread
impl Automatchread