#[repr(u8)]pub enum Mstarbloss {
NO_LOSS = 0,
ARBITRATION_LOSS = 1,
}Variants
NO_LOSS = 0
No Arbitration Loss has occurred.
ARBITRATION_LOSS = 1
Arbitration loss. The Master function has experienced an Arbitration Loss. At this point, the Master function has already stopped driving the bus and gone to an idle state. Software can respond by doing nothing, or by sending a Start in order to attempt to gain control of the bus when it next becomes idle.
Implementations
Sourceimpl Mstarbloss
impl Mstarbloss